Returns a list with the aggregate fit metadata and per-CS summaries; can be printed for human inspection.
Usage
# S3 method for class 'mfsusie'
summary(object, ...)Returns a list with the aggregate fit metadata and per-CS summaries; can be printed for human inspection.
# S3 method for class 'mfsusie'
summary(object, ...)